@@ -1,7 +1,7 @@
 g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
                       quantiletype = 7, includedaycrit = 16, 
-                      idloc = 1, snloc = 1, selectdaysfile=c(), 
-                      dayborder=0,  desiredtz = "", myfun=c(), ...) {
+                      idloc = 1, snloc = 1, selectdaysfile = c(), 
+                      dayborder = 0,  desiredtz = "", myfun = c(), acc.metric = c(), ...) {
   
   #get input variables
   input = list(...)
@@ -49,7 +49,7 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
   # Extracting basic information about the file
   hvars = g.extractheadervars(I)
   ID = hvars$ID;              iID = hvars$iID; IDd = hvars$IDd
-  HN = hvars$HN;              BodyLocation = hvars$BodyLocation
+  HN = hvars$HN;              sensor.location = hvars$sensor.location
   SX = hvars$SX;                deviceSerialNumber = hvars$deviceSerialNumber
   n_ws2_perday = (1440*60) / ws2
   n_ws3_perday = (1440*60) / ws3
@@ -234,7 +234,8 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
                                  M = M, IMP = IMP, t_TWDI = t_TWDI,
                                  quantiletype = quantiletype, ws3 = ws3,
                                  doiglevels = doiglevels, firstmidnighti = firstmidnighti, ws2 = ws2,
-                                 midnightsi = midnightsi, params_247 = params_247)
+                                 midnightsi = midnightsi, params_247 = params_247, qcheck = qcheck,
+                                 acc.metric = acc.metric)
   InterdailyStability = output_avday$InterdailyStability
   IntradailyVariability = output_avday$IntradailyVariability
   igfullr_names = output_avday$igfullr_names
@@ -243,6 +244,9 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
   qlevels_names = output_avday$qlevels_names
   ML5AD = output_avday$ML5AD
   ML5AD_names = output_avday$ML5AD_names
+  
+  cosinor_coef = output_avday$cosinor_coef
+  
   #--------------------------------------------------------------
   # Analysis per day
   if (doperday == TRUE) {
@@ -253,7 +257,7 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
                                      doiglevels = doiglevels, nfulldays = nfulldays,
                                      lastmidnight = lastmidnight,
                                      ws3 = ws3, ws2 = ws2, qcheck = qcheck, fname = fname,
-                                     idloc = idloc, BodyLocation = BodyLocation, wdayname = wdayname,
+                                     idloc = idloc, sensor.location = sensor.location, wdayname = wdayname,
                                      tooshort = tooshort, includedaycrit = includedaycrit,
                                      quantiletype = quantiletype, doilevels = doilevels, 
                                      domvpa = domvpa,
@@ -317,21 +321,27 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
   }
   rm(metalong); rm(metashort)
   
-  output_perfile = g.analyse.perfile(ID, fname, deviceSerialNumber, BodyLocation, startt, I, LC2, LD, dcomplscore,
+  output_perfile = g.analyse.perfile(ID, fname, deviceSerialNumber, sensor.location, startt, I, LC2, LD, dcomplscore,
                                      LMp, LWp, C, lookat, AveAccAve24hr, colnames_to_lookat, QUAN, ML5AD,
                                      ML5AD_names, igfullr, igfullr_names,
                                      daysummary, ds_names, includedaycrit, strategy, hrs.del.start,
                                      hrs.del.end, maxdur, windowsizes, idloc, snloc, wdayname, doquan,
                                      qlevels_names, doiglevels, tooshort, InterdailyStability, IntradailyVariability,
                                      IVIS_windowsize_minutes = params_247[["IVIS_windowsize_minutes"]],
-                                     qwindow = params_247[["qwindow"]], longitudinal_axis_id)
+                                     qwindow = params_247[["qwindow"]], longitudinal_axis_id, cosinor_coef)
   filesummary = output_perfile$filesummary
   daysummary = output_perfile$daysummary
+  
+  if (length(cosinor_coef) > 0) {
+    cosinor_ts = cosinor_coef$coefext$cosinor_ts
+  } else {
+    cosinor_ts = c()
+  }
   if (length(selectdaysfile) > 0) {
     windowsummary = data.frame(windowsummary,stringsAsFactors = FALSE) # addition for Millenium cohort
     names(windowsummary) = ws_names
-    invisible(list(summary = filesummary, daysummary = daysummary, windowsummary = windowsummary))
+    invisible(list(summary = filesummary, daysummary = daysummary, windowsummary = windowsummary, cosinor_ts = cosinor_ts))
   } else {
-    invisible(list(summary = filesummary, daysummary = daysummary))
+    invisible(list(summary = filesummary, daysummary = daysummary, cosinor_ts = cosinor_ts))
   }
 }
