@@ -27,7 +27,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   if (length(input) > 0) {
     for (i in 1:length(names(input))) {
       txt = paste0(names(input)[i], "=", input[i])
-      if (class(unlist(input[i])) == "character") {
+      if (is(unlist(input[i]), "character")) {
         txt = paste0(names(input)[i], "='", unlist(input[i]), "'")
       }
       eval(parse(text = txt))
@@ -148,6 +148,10 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   sf = INFI$sf
   hvars = g.extractheadervars(INFI)
   deviceSerialNumber = hvars$deviceSerialNumber
+  # if GENEActiv csv, deprecated function
+  if (mon == 2 & dformat == 2 & length(params_rawdata[["rmc.firstrow.acc"]]) == 0) {
+    stop("The GENEActiv csv reading functionality is deprecated in GGIR from the version 2.6-4 onwards. Please, use either the GENEActiv bin files or try to read the csv files with GGIR::read.myacc.csv")
+  }
   if (mon == 3) {
     # If Actigraph then try to specify dynamic range based on Actigraph model
     if (length(grep(pattern = "CLE", x = deviceSerialNumber)) == 1) {
@@ -424,7 +428,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
             if (ncol(data) == 3) data = data[,1:3]
             if (ncol(data) >= 4) {
               data = data[,2:4]
-              if (class(data[,1]) == "character") {
+              if (is(data[,1], "character")) {
                 data = apply(data, 2,as.numeric)
               }
             }
